API Reference
=============


.. autoclass:: jaxlogit.mixed_logit.MixedLogit
   :members: fit, predict

.. autosummary::
   :toctree: _autosummary

   jaxlogit._config_data.ConfigData
   jaxlogit.utils.wide_to_long
   jaxlogit.scikit_wrapper.MixedLogitEstimator